@@ -17,8 +17,8 @@
 # 
 # You should have received a copy of the GNU General Public License
 # along with this program; see the file COPYING. If not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-# MA 02111-1307, USA.
+# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+# Boston, MA  02110-1301 USA.
 
 import sys, os, os.path, distutils.util
 
@@ -52,9 +52,8 @@ class DocDirectoryCannotBeCleaned(error):
 
 def check_if_program_looks_built(build_dir):
     package_dir = os.path.join(build_dir, "xmms")
-    files = ["__init__.py", "common.py", "control.py", "_xmmscontrol.so"]
-    if sys.hexversion >= 0x02020000:
-        files.extend(("config.py", "_xmmsconfig.so"))
+    files = ["__init__.py", "common.py", "control.py", "_xmmscontrol.so",
+             "config.py", "_xmmsconfig.so"]
 
     if not os.path.isdir(package_dir):
         raise ProgramDoesNotLookBuilt("%s is not an existing directory"
@@ -67,25 +66,12 @@ def check_if_program_looks_built(build_dir):
 
 
 def build_documentation(build_dir):
-    # Modules that are available to all Python versions supported by PyXMMS.
-    all_pyversions_modules = ["common", "control"]
-    # Modules that are only available on Python >= 2.2
-    recent_pyversions_modules = ["config"]
-    # Generate the list of modules to feed to pydoc
-    modules = all_pyversions_modules[:]
-    if sys.hexversion >= 0x02020000:
-        modules.extend(recent_pyversions_modules)
-    else:
-        sys.stderr.write("Warning: this Python is 2.1 or earlier, so only "
-                         "part of the PyXMMS documentation will be built.\n")
-        
+    modules = ["common", "control", "config"]
     base_dir = os.getcwd()
 
-    # First, erase the existing documentation (especially useful if there is a
-    # xmms.config.html left and we are building the documentation with
-    # Python2.1).
+    # First, erase the existing documentation
     os.chdir(doc_dir)
-    for module in all_pyversions_modules + recent_pyversions_modules:
+    for module in modules:
         doc_filename = "xmms.%s.html" % module
         if os.path.isfile(doc_filename):
             os.unlink(doc_filename)
