@@ -14,8 +14,8 @@
 # 
 # You should have received a copy of the GNU General Public License
 # along with this program; see the file COPYING. If not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-# MA 02111-1307, USA.
+# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+# Boston, MA  02110-1301 USA.
 
 """Python interface to XMMS --- initialization of the xmms package.
 
@@ -25,10 +25,7 @@ This file contains initialization code for the xmms package.
 
 import sys
 
-__all__ = ["common", "control"]
-# The config module requires Python >= 2.2
-if sys.hexversion >= 0x02020000:
-    __all__.append("config")
+__all__ = ["common", "control", "config"]
 
 # This brings us common.error, which is expected to be here
 from common import *
