@@ -14,8 +14,8 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with PyXMMS; see the file COPYING. If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+Boston, MA  02110-1301 USA. */
 
 #include <Python.h>             /* Must come first */
 #include <string.h>
@@ -282,10 +282,9 @@ static PyObject *func_void_glist(void (*func)(gint, GList *),
                                  char *warning_msg)
 {
     int session = 0;
-    PyObject *seq, *item;
-    PyObject *fast_seq = NULL;
+    PyObject *seq, *py_str;
+    PyObject *item = NULL;
     int seq_len;
-    char *msg_not_a_sequence = "first argument must be a sequence";
     guint i;
     char *py_internal_str;
     gchar *string;
@@ -299,20 +298,29 @@ static PyObject *func_void_glist(void (*func)(gint, GList *),
     if (!PyArg_ParseTuple(args, "O|i", &seq, &session))
         return NULL;
 
-    if ((fast_seq = PySequence_Fast(seq, msg_not_a_sequence)) == NULL)
-        return NULL;
-    
-    /* Would be OK on Python >= 2.2
-    for (i=0; i < PySequence_Fast_GET_SIZE(fast_seq); i++)
-    */
-
     if ((seq_len = PySequence_Size(seq)) == -1)
-        goto error;
+        return NULL;
         
     for (i=0; i < seq_len; i++)
         {
-            /* Retreive a string from the sequence */
-            item = PySequence_Fast_GET_ITEM(fast_seq, i);
+            /* Retreive an element from the sequence */
+            if ((item = PySequence_GetItem(seq, i)) == NULL)
+                return NULL;
+
+            /* Is it an Unicode object? */
+            if (PyUnicode_Check(item))
+                {
+                    /* Yes -> encode it to a regular string */
+                    if ((py_str = PyUnicode_AsEncodedString(
+                             item, Py_FileSystemDefaultEncoding,
+                             "strict")) == NULL)
+                        goto error;
+                    
+                    Py_DECREF(item); /* We don't need the Unicode object
+                                      * anymore. */
+                    item = py_str; /* item becomes a simple string */
+                }
+            
             if ((py_internal_str = PyString_AsString(item)) == NULL)
                 goto error;
 
@@ -323,6 +331,7 @@ static PyObject *func_void_glist(void (*func)(gint, GList *),
                     goto error;
                 }
 
+            Py_DECREF(item);
             strings = g_list_append(strings, string);
         }
     
@@ -335,82 +344,88 @@ static PyObject *func_void_glist(void (*func)(gint, GList *),
     /* Free the list */
     g_list_free(strings);
 
-    Py_DECREF(fast_seq);
-
     Py_INCREF(Py_None);
     return Py_None;
 
   error:
-    Py_XDECREF(fast_seq);
+    Py_XDECREF(item);
     /* The exception must be set at this point */
     return NULL;
 }
 
 /* Here follow the libxmms bindings */
 
-/* XXXwatch */
 PyDoc_STRVAR(playlist_doc,
-"Set the playlist contents or enqueue files/URLs in it.\n\
+"Set the playlist contents and start playing, or enqueue files/URLs.\n\
 \n\
 playlist(seq, enqueue, session=0) -> None\n\
 \n\
 seq     -- a sequence of files/URLs\n\
-enqueue -- boolean (0 = false, 1 = true); false does not work in\n\
-           xmms 1.2.6.\n\
-session -- the XMMS session to act on");
+enqueue -- boolean (0 = false, 1 = true)\n\
+session -- the XMMS session to act on\n\
+\n\
+If `enqueue' is false, the playlist is set according to `seq' and\n\
+XMMS starts playing from the first entry. If true, the files or\n\
+URLs are simply added to the playlist and the playing/not playing\n\
+status is left unchanged.");
 
 static PyObject *pywrap_xmms_remote_playlist(PyObject *self,
                                              PyObject *args)
 {
     int session = 0;
     int enqueue;
-    PyObject *seq, *item;
-    PyObject *fast_seq = NULL;
+    PyObject *seq, *py_str;
+    PyObject *item = NULL;
     int seq_len;
     char **str_list;
     guint i;
-    char *str;
+    char *py_internal_str;
     
     if (!PyArg_ParseTuple(args, "Oi|i", &seq, &enqueue, &session))
         return NULL;
 
-    if ((fast_seq = PySequence_Fast(seq,
-                                    "first argument of playlist_add is not a "
-                                    "sequence")) == NULL)
-        return NULL;
-    
     if ((seq_len = PySequence_Size(seq)) == -1)
-        goto error;
+        return NULL;
         
     if ((str_list = malloc(seq_len * sizeof(char *))) == NULL)
         {
             PyErr_SetFromErrno(PyExc_MemoryError);
-            goto error;
+            return NULL;
         }
 
     for (i=0; i < seq_len; i++)
         {
-            item = PySequence_Fast_GET_ITEM(fast_seq, i);
-            if ((str = PyString_AsString(item)) == NULL)
+            /* Retreive an element from the sequence */
+            if ((item = PySequence_GetItem(seq, i)) == NULL)
+                return NULL;
+
+            /* Is it an Unicode object? */
+            if (PyUnicode_Check(item))
+                {
+                    /* Yes -> encode it to a regular string */
+                    if ((py_str = PyUnicode_AsEncodedString(
+                             item, Py_FileSystemDefaultEncoding,
+                             "strict")) == NULL)
+                        goto error;
+                    
+                    Py_DECREF(item); /* We don't need the Unicode object
+                                      * anymore. */
+                    item = py_str; /* item becomes a simple string */
+                }
+            
+            if ((py_internal_str = PyString_AsString(item)) == NULL)
                 goto error;
 
             /* In case xmms would write to the string... */
-            if ((str_list[i] = strdup(str)) == NULL)
+            if ((str_list[i] = strdup(py_internal_str)) == NULL)
                 {
                     PyErr_SetFromErrno(PyExc_MemoryError);
                     goto error;
                 }
+
+            Py_DECREF(item);
         }
     
-    /* XXXwatch It seems that xmms 1.2.6-1.2.7 don't like to get enqueue =
-       FALSE here (it _never_ happens in xmms 1.2.6 code---I did not check
-       with other versions)
-    */
-/*     printf("session: %d\nseq_len: %d\nenqueue: %d\n", */
-/*            session, seq_len, enqueue); */
-/*     for (i=0; i < seq_len; i++) */
-/*         printf("%s\n", str_list[i]); */
-
     xmms_remote_playlist(session, str_list, seq_len, PYXMMS_GBOOL(enqueue));
 
     for (i=0; i < seq_len; i++)
@@ -418,13 +433,11 @@ static PyObject *pywrap_xmms_remote_playlist(PyObject *self,
 
     free(str_list);
     
-    Py_DECREF(fast_seq);
-
     Py_INCREF(Py_None);
     return Py_None;
 
   error:
-    Py_XDECREF(fast_seq);
+    Py_XDECREF(item);
     /* The exception must be set at this point */
     return NULL;
 }
